<template>
  <div class="rightContent">
    <div class="top">
      <div>
        <SearchCommonView
          :add-title="'新建'"
          :showAdd="true"
          :placeholder="'请输入参考'"
          :amount-view="false"
          @addCommonClick="addBtnClick"
          @searchClick="getList"
        />
      </div>
    </div>
    <div class="list-view">
      <TableCommonView
        ref="tableListRef"
        :table-list="tableList"
        @selTableCol="selTableCol"
        @tableRowClick="tableRowClick"
      >
        <template slot="tableButton">
          <el-table-column
            label="操作"
            width="210"
            align="center"
          >
            <template slot-scope="scope">
              <span @click="handleHistoryClick(scope.row)">
                <i class="el-icon-refresh-left"></i>
                <span>历史</span>
              </span>
              <span @click="handleAddGoods(scope)" class="margin_left_5px">
                <i class="el-icon-refresh"></i>
                <span>补货</span>
              </span>
            </template>
          </el-table-column>
        </template>
      </TableCommonView>
      <div class="btn-pager">
        <PagerView
          class="page"
          :pager-options="pagerOptions"
          v-on="pagerEvents"
        />
      </div>
    </div>
    <!-- 编辑 -->
    <AddOverviewDialog
      v-if="editConfig.visible"
      :edit-common-config="editConfig"
      :add-name="this.$route.params.name"
    />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin";
import { getProductOperatonList } from "@/api/product/product";
import AddOverviewDialog from "@/views/overview/AddOverviewDialog";

export default {
  name: "InventoryReport",
  props: {},
  components: { AddOverviewDialog },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      showcol: ["存储类别", "产品类别", "预留数量", "价值"],
      testArr: [
        {
          product:"HC/销售区/b区",
          category:"丝绸制品/真丝睡袍",
          cost:"800.00",
          totalPrices:"0.00",
          inStore:"0.00",
          availableStore:"0.00",
          inStorage:"0.00",
          toStore:"0.00",
          forecast:"0.00",
          unit:"件"
        },
        {
          product:"HC销售区/A区",
          category:"丝绸制品/真丝睡袍",
          cost:"9980.00",
          totalPrices:"0.00",
          inStore:"0.00",
          availableStore:"0.00",
          inStorage:"0.00",
          toStore:"0.00",
          forecast:"0.00",
          unit:"件"
        },
      ],
      searchOptions: [],
      commonDetail: {
        visible: false,
        title: "新建",
        infomation: {},
      },
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {},
      },
      productId: this.$route.params.id,
      productName: this.$route.params.name,
    };
  },
  created() {
    this.setTable();
    // this.getData();
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation:[],
        selectBox: true,
        showcol: this.showcol,
        allcol: [],
        tableColumn: this.setTableColumn(this.showcol),
      };
      let allcol = [];
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        if (!this.tableList.tableColumn[i].default) {
          const label = this.tableList.tableColumn[i].label;
          allcol.push(label);
        }
      }
      this.tableList.allcol = allcol;
      this.tableList.tableInfomation=this.testArr
    },
    setTableColumn(showcol) {
      let tableColumn = [
        /* 
          product:"南方丝巢xxx",
          category:"丝绸制品/真丝睡袍",
          cost:"800.00",
          totalPrices:"0.00",
          inStore:"0.00",
          availableStore:"0.00",
          inStorage:"0.00",
          toStore:"0.00",
          forecast:"0.00",
          unit:"件"
        */
        {
          label: "位置",
          prop: "product",
          isShowColumn: true,
          default: true,
        },

        {
          label: "存储类别",
          prop: "category",
          isShowColumn: true,
          default: false,
          isShowColumn: showcol.includes("存储类别"),
        },
        {
          label: "产品",
          prop: "cost",
          isShowColumn: true,
          default: true,
        },
        {
          label: "产品类别",
          prop: "totalPrices",
          isShowColumn: true,
          default: false,
          isShowColumn: showcol.includes("产品类别"),
        },
        {
          label: "在库数量",
          prop: "inStore",
          isShowColumn: true,
          default: true,
        },
        {
          label: "预留数量",
          prop: "availableStore",
          // isShowColumn: true,
          default: false,
          isShowColumn: showcol.includes("预留数量"),
        },
        {
          label: "单位",
          prop: "unit",
          isShowColumn: true,
          default: true,
        },
        {
          label: "价值",
          prop: "toStore",
          width: 120,
          default: false,
          // status: true,
          // isCallMethod: true,
          // getCallMethod: this.getStatus,
          isShowColumn: showcol.includes("价值"),
        },
      ];
      return tableColumn;
    },
    selTableCol(val) {
      this.showcol = val;
      this.tableList.tableColumn = this.setTableColumn(val);
    },
    // 请求数据
    // async getData() {
    //   await getProductOperatonList({
    //     productId: this.productId,
    //     page: this.pagerOptions.currPage,
    //     pageSize: this.pagerOptions.pageSize,
    //   }).then((res) => {
    //     if (res.code === 200) {
    //       const list = res.data.map((item) => {
    //         return {
    //           ...item,
    //           from: item.fromLocation.name,
    //           to: item.toLocation.name,
    //           productName: this.productName,
    //         };
    //       });
    //       this.tableList.tableInfomation = list || [];
    //       this.pagerOptions.totalCount = res.total;
    //     }
    //   });
    // },

    // 搜索
    getList(val) {
      console.log(val);
    },
    // 行点击
    tableRowClick(row) {
      console.log(row);
      this.editConfig.visible = true;
      this.editConfig.title = "查看";
      this.editConfig.infomation = { ...row };
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true;
      this.editConfig.title = "新建";
    },
    // 状态
    getStatus(val) {
      return val === 1 ? "草稿" : val === 3 ? "就绪" : "完成";
    },
    // 历史
    handleHistoryClick(){

    },
    // 补货
    handleAddGoods(){

    }
  },
};
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped>
.rightContent {
  height: 100%;
  background: #e6ecf2;
  padding: 10px;
// .top {
//   margin-bottom: 20px;
//   height: 60px;
//   background: #fff;
//   border-radius: 8px;
// }
  .list-view {
    height: calc(100% - 150px);
  }
}
</style>
